@@ -43,13 +43,13 @@ NULL
 ##' @export
 mvn_diag_rw <- function (rw.sd) {
   if (missing(rw.sd) || !is.numeric(rw.sd)) {
-    pStop("mvn_diag_rw",sQuote("rw.sd")," must be a named numeric vector.")
+    pStop(sQuote("rw.sd")," must be a named numeric vector.")
   }
   rw.sd <- rw.sd[rw.sd>0]
   parnm <- names(rw.sd)
   n <- length(rw.sd)
   if (is.null(parnm))
-    pStop("mvn_diag_rw",sQuote("rw.sd")," must have names.")
+    pStop(sQuote("rw.sd")," must have names.")
   function (theta, ...) {
     theta[parnm] <- rnorm(n=n,mean=theta[parnm],sd=rw.sd)
     theta
@@ -61,14 +61,13 @@ mvn_diag_rw <- function (rw.sd) {
 mvn_rw <- function (rw.var) {
   rw.var <- as.matrix(rw.var)
   parnm <- colnames(rw.var)
-  ep <- "mvn_rw"
   if (is.null(parnm))
-    pStop(ep,sQuote("rw.var")," must have row- and column-names.")
+    pStop(sQuote("rw.var")," must have row- and column-names.")
   if (nrow(rw.var)!=ncol(rw.var))
-    pStop(ep,sQuote("rw.var")," must be a square matrix.")
+    pStop(sQuote("rw.var")," must be a square matrix.")
   ch <- chol(rw.var,pivot=TRUE)
   if (attr(ch,"rank") < ncol(ch))
-    pWarn(ep,"rank-deficient covariance matrix")
+    pWarn("rank-deficient covariance matrix")
   oo <- order(attr(ch,"pivot"))
   n <- Q <- NULL                 # to evade R CMD check false positive
   e <- new.env()
@@ -89,24 +88,22 @@ mvn_rw <- function (rw.var) {
 mvn_rw_adaptive <- function (rw.sd, rw.var, scale.start = NA,
   scale.cooling = 0.999, shape.start = NA, target = 0.234, max.scaling = 50) {
 
-  ep <- "mvn_rw_adaptive"
-
   if (!xor(missing(rw.sd),missing(rw.var))) {
-    pStop(ep,"exactly one of ",sQuote("rw.sd")," and ",sQuote("rw.var"),
+    pStop("exactly one of ",sQuote("rw.sd")," and ",sQuote("rw.var"),
       " must be supplied.")
   }
   if (!missing(rw.var)) { ## variance supplied
     rw.var <- as.matrix(rw.var)
     parnm <- colnames(rw.var)
     if (is.null(parnm))
-      pStop(ep,sQuote("rw.var")," must have row- and column-names.")
+      pStop(sQuote("rw.var")," must have row- and column-names.")
     if (nrow(rw.var)!=ncol(rw.var))
-      pStop(ep,sQuote("rw.var")," must be a square matrix.")
+      pStop(sQuote("rw.var")," must be a square matrix.")
     if (any(parnm!=rownames(rw.var)))
-      pStop(ep,"row- and column-names of ",sQuote("rw.var")," must agree.")
+      pStop("row- and column-names of ",sQuote("rw.var")," must agree.")
   } else if (!missing(rw.sd)) { ## sd supplied (diagonal)
     if (!is.numeric(rw.sd) || is.null(names(rw.sd))) {
-      pStop(ep,sQuote("rw.sd")," must be a named numeric vector.")
+      pStop(sQuote("rw.sd")," must be a named numeric vector.")
     }
     rw.sd <- rw.sd[rw.sd>0]
     parnm <- names(rw.sd)
@@ -119,13 +116,13 @@ mvn_rw_adaptive <- function (rw.sd, rw.var, scale.start = NA,
   shape.start <- as.integer(shape.start)
   target <- as.numeric(target) ## target acceptance ratio
   if (!isTRUE(scale.start > 0))
-    pStop(ep,sQuote("scale.start")," must be a positive integer.")
+    pStop(sQuote("scale.start")," must be a positive integer.")
   if (!isTRUE((scale.cooling > 0) && (scale.cooling <= 1)))
-    pStop(ep,sQuote("scale.cooling")," must be in (0,1].")
+    pStop(sQuote("scale.cooling")," must be in (0,1].")
   if (!isTRUE(shape.start > 0))
-    pStop(ep,sQuote("shape.start")," must be a positive integer.")
+    pStop(sQuote("shape.start")," must be a positive integer.")
   if (!isTRUE(target > 0 && target < 1)) {
-    pStop(ep,sQuote("target")," must be a number in (0,1).")
+    pStop(sQuote("target")," must be a number in (0,1).")
   }
 
   ## variables that will follow 'f'
@@ -158,7 +155,8 @@ mvn_rw_adaptive <- function (rw.sd, rw.var, scale.start = NA,
       covmat.emp <<- ((.n-1)*covmat.emp+tcrossprod(theta[parnm]-theta.mean))/.n
     }
     ch <- chol(covmat,pivot=TRUE)
-    if (attr(ch,"rank")<length(parnm)) pWarn(ep,"degenerate proposal.")
+    if (attr(ch,"rank")<length(parnm))
+      pWarn(who="mvn_rw_adaptive","degenerate proposal.")
     oo <- order(attr(ch,"pivot"))
     Q <- ch[,oo]
     theta[parnm] <- theta[parnm]+rnorm(n=length(parnm),mean=0,sd=1)%*%Q
