@@ -52,8 +52,9 @@ static const R_CallMethodDef callMethods[] = {
 
 void R_init_pomp (DllInfo *info) {
   // C functions provided for users
-  R_RegisterCCallable("pomp","bspline_eval",(DL_FUNC) &bspline_eval);
-  R_RegisterCCallable("pomp","periodic_bspline_basis_eval",(DL_FUNC) &periodic_bspline_basis_eval);
+  R_RegisterCCallable("pomp","bspline_basis_eval_deriv",(DL_FUNC) &bspline_basis_eval_deriv);
+  R_RegisterCCallable("pomp","periodic_bspline_basis_eval_deriv",(DL_FUNC) &periodic_bspline_basis_eval_deriv);
+  R_RegisterCCallable("pomp","bspline_eval",(DL_FUNC) &bspline_eval); /* DEPRECATED */
   R_RegisterCCallable("pomp","get_userdata",(DL_FUNC) &get_userdata);
   R_RegisterCCallable("pomp","get_userdata_int",(DL_FUNC) &get_userdata_int);
   R_RegisterCCallable("pomp","get_userdata_double",(DL_FUNC) &get_userdata_double);
