@@ -4,11 +4,8 @@
 #include <Rmath.h>
 #include <Rdefines.h>
 #include <Rinternals.h>
-#include <R_ext/Rdynload.h>
-#include <R_ext/Arith.h>
-#include <string.h>
 
-#include "pomp_internal.h"
+#include "internal.h"
 
 static R_INLINE SEXP add_args (SEXP args, SEXP Snames, SEXP Pnames, SEXP Cnames)
 {
@@ -16,7 +13,7 @@ static R_INLINE SEXP add_args (SEXP args, SEXP Snames, SEXP Pnames, SEXP Cnames)
   SEXP var;
   int v;
 
-  PROTECT(args);
+  PROTECT(args = VectorToPairList(args));
 
   // we construct the call from end to beginning
   // covariates, parameter, states, then time
@@ -61,11 +58,11 @@ static R_INLINE SEXP add_args (SEXP args, SEXP Snames, SEXP Pnames, SEXP Cnames)
 }
 
 static R_INLINE SEXP eval_call (
-    SEXP fn, SEXP args,
-    double *t,
-    double *x, int nvar,
-    double *p, int npar,
-    double *c, int ncov)
+                                SEXP fn, SEXP args,
+                                double *t,
+                                double *x, int nvar,
+                                double *p, int npar,
+                                double *c, int ncov)
 {
 
   SEXP var = args, ans, ob;
@@ -149,11 +146,11 @@ SEXP do_rmeasure (SEXP object, SEXP x, SEXP times, SEXP params, SEXP gnsi)
   PROTECT(fn = pomp_fun_handler(pompfun,gnsi,&mode,Snames,Pnames,Onames,Cnames));
 
   // extract 'userdata' as pairlist
-  PROTECT(args = VectorToPairList(GET_SLOT(object,install("userdata"))));
+  PROTECT(args = GET_SLOT(object,install("userdata")));
 
   int nprotect = 11;
   int first = 1;
-  
+
   // first do setup
   switch (mode) {
 
@@ -167,7 +164,7 @@ SEXP do_rmeasure (SEXP object, SEXP x, SEXP times, SEXP params, SEXP gnsi)
 
     for (k = 0; k < ntimes; k++, time++) { // loop over times
 
-      R_CheckUserInterrupt();	// check for user interrupt
+      R_CheckUserInterrupt();   // check for user interrupt
 
       table_lookup(&covariate_table,*time,cov); // interpolate the covariates
 
@@ -176,14 +173,14 @@ SEXP do_rmeasure (SEXP object, SEXP x, SEXP times, SEXP params, SEXP gnsi)
         if (first) {
 
           PROTECT(
-            ans = eval_call(
-              fn,args,
-              time,
-              xs+nvars*((j%nrepsx)+nrepsx*k),nvars,
-              ps+npars*(j%nrepsp),npars,
-              cov,ncovars
-            )
-	  );
+                  ans = eval_call(
+                                  fn,args,
+                                  time,
+                                  xs+nvars*((j%nrepsx)+nrepsx*k),nvars,
+                                  ps+npars*(j%nrepsp),npars,
+                                  cov,ncovars
+                                  )
+                  );
 
           nobs = LENGTH(ans);
 
@@ -193,7 +190,7 @@ SEXP do_rmeasure (SEXP object, SEXP x, SEXP times, SEXP params, SEXP gnsi)
 
           PROTECT(Y = ret_array(nobs,nreps,ntimes,Onames));
 
-	  nprotect += 3;
+          nprotect += 3;
 
           yt = REAL(Y);
           ys = REAL(AS_NUMERIC(ans));
@@ -201,19 +198,19 @@ SEXP do_rmeasure (SEXP object, SEXP x, SEXP times, SEXP params, SEXP gnsi)
           memcpy(yt,ys,nobs*sizeof(double));
           yt += nobs;
 
-	  first = 0;
+          first = 0;
 
         } else {
 
           PROTECT(
-            ans = eval_call(
-              fn,args,
-              time,
-              xs+nvars*((j%nrepsx)+nrepsx*k),nvars,
-              ps+npars*(j%nrepsp),npars,
-              cov,ncovars
-            )
-          );
+                  ans = eval_call(
+                                  fn,args,
+                                  time,
+                                  xs+nvars*((j%nrepsx)+nrepsx*k),nvars,
+                                  ps+npars*(j%nrepsp),npars,
+                                  cov,ncovars
+                                  )
+                  );
 
           if (LENGTH(ans) != nobs)
             err("'rmeasure' returns variable-length results.");
@@ -238,7 +235,7 @@ SEXP do_rmeasure (SEXP object, SEXP x, SEXP times, SEXP params, SEXP gnsi)
     double *yt = 0, *xp, *pp;
     double *time = REAL(times), *xs = REAL(x), *ps = REAL(params);
     int *oidx, *sidx, *pidx, *cidx;
-    pomp_measure_model_simulator *ff = NULL;
+    pomp_rmeasure *ff = NULL;
     int j, k;
 
     nobs = LENGTH(Onames);
@@ -254,12 +251,11 @@ SEXP do_rmeasure (SEXP object, SEXP x, SEXP times, SEXP params, SEXP gnsi)
     PROTECT(Y = ret_array(nobs,nreps,ntimes,Onames)); nprotect++;
     yt = REAL(Y);
 
-    set_pomp_userdata(args);
     GetRNGstate();
 
     for (k = 0; k < ntimes; k++, time++) { // loop over times
 
-      R_CheckUserInterrupt();	// check for user interrupt
+      R_CheckUserInterrupt();   // check for user interrupt
 
       // interpolate the covar functions for the covariates
       table_lookup(&covariate_table,*time,cov);
@@ -275,7 +271,6 @@ SEXP do_rmeasure (SEXP object, SEXP x, SEXP times, SEXP params, SEXP gnsi)
     }
 
     PutRNGstate();
-    unset_pomp_userdata();
 
   }
 
